@@ -1,5 +1,4 @@
-use std::collections::BTreeSet;
-
+use fnv::FnvHashSet;
 use once_cell::sync::Lazy;
 
 use crate::docstrings::google::{GOOGLE_SECTION_NAMES, LOWERCASE_GOOGLE_SECTION_NAMES};
@@ -11,14 +10,14 @@ pub(crate) enum SectionStyle {
 }
 
 impl SectionStyle {
-    pub(crate) fn section_names(&self) -> &Lazy<BTreeSet<&'static str>> {
+    pub(crate) fn section_names(&self) -> &Lazy<FnvHashSet<&'static str>> {
         match self {
             SectionStyle::NumPy => &NUMPY_SECTION_NAMES,
             SectionStyle::Google => &GOOGLE_SECTION_NAMES,
         }
     }
 
-    pub(crate) fn lowercase_section_names(&self) -> &Lazy<BTreeSet<&'static str>> {
+    pub(crate) fn lowercase_section_names(&self) -> &Lazy<FnvHashSet<&'static str>> {
         match self {
             SectionStyle::NumPy => &LOWERCASE_NUMPY_SECTION_NAMES,
             SectionStyle::Google => &LOWERCASE_GOOGLE_SECTION_NAMES,
