@@ -1,16 +1,18 @@
 use rustpython_ast::Expr;
 
-use crate::ast::helpers::{compose_call_path, match_call_path};
+use crate::ast::helpers::{collect_call_paths, match_call_path};
 use crate::ast::types::Range;
 use crate::check_ast::Checker;
 use crate::checks::{Check, CheckKind};
 
 /// B005
 pub fn useless_contextlib_suppress(checker: &mut Checker, expr: &Expr, args: &[Expr]) {
-    if compose_call_path(expr)
-        .map(|call_path| match_call_path(&call_path, "contextlib.suppress", &checker.from_imports))
-        .unwrap_or(false)
-        && args.is_empty()
+    if match_call_path(
+        &collect_call_paths(expr),
+        "contextlib",
+        "suppress",
+        &checker.from_imports,
+    ) && args.is_empty()
     {
         checker.add_check(Check::new(
             CheckKind::UselessContextlibSuppress,
