@@ -1,8 +1,9 @@
 use anyhow::Result;
 use libcst_native::{
-    Arg, Call, Codegen, Dict, DictComp, DictElement, Element, Expr, Expression, LeftCurlyBrace,
-    LeftParen, LeftSquareBracket, List, ListComp, Name, ParenthesizableWhitespace, RightCurlyBrace,
-    RightParen, RightSquareBracket, Set, SetComp, SimpleString, SimpleWhitespace, Tuple,
+    Arg, AssignEqual, Call, Codegen, Dict, DictComp, DictElement, Element, Expr, Expression,
+    LeftCurlyBrace, LeftParen, LeftSquareBracket, List, ListComp, Name, ParenthesizableWhitespace,
+    RightCurlyBrace, RightParen, RightSquareBracket, Set, SetComp, SimpleString, SimpleWhitespace,
+    Tuple,
 };
 
 use crate::ast::types::Range;
@@ -220,6 +221,64 @@ pub fn fix_unnecessary_list_comprehension_set(
     ))
 }
 
+/// (C404) Convert `dict([(i, i) for i in range(3)])` to `{i: i for i in
+/// range(3)}`.
+pub fn fix_unnecessary_list_comprehension_dict(
+    locator: &SourceCodeLocator,
+    expr: &rustpython_ast::Expr,
+) -> Result<Fix> {
+    let module_text = locator.slice_source_code_range(&Range::from_located(expr));
+    let mut tree = match_module(&module_text)?;
+    let mut body = match_expr(&mut tree)?;
+    let call = match_call(body)?;
+    let arg = match_arg(call)?;
+
+    let list_comp = if let Expression::ListComp(list_comp) = &arg.value {
+        list_comp
+    } else {
+        return Err(anyhow::anyhow!("Expected node to be: Expression::ListComp"));
+    };
+
+    let tuple = if let Expression::Tuple(tuple) = &*list_comp.elt {
+        tuple
+    } else {
+        return Err(anyhow::anyhow!("Expected node to be: Expression::Tuple"));
+    };
+
+    let (key, comma, value) = match &tuple.elements[..] {
+        [Element::Simple {
+            value: key,
+            comma: Some(comma),
+        }, Element::Simple { value, .. }] => (key, comma, value),
+        _ => return Err(anyhow::anyhow!("Expected tuple with two elements")),
+    };
+
+    body.value = Expression::DictComp(Box::new(DictComp {
+        key: Box::new(key.clone()),
+        value: Box::new(value.clone()),
+        for_in: list_comp.for_in.clone(),
+        whitespace_before_colon: comma.whitespace_before.clone(),
+        whitespace_after_colon: comma.whitespace_after.clone(),
+        lbrace: LeftCurlyBrace {
+            whitespace_after: call.whitespace_before_args.clone(),
+        },
+        rbrace: RightCurlyBrace {
+            whitespace_before: arg.whitespace_after_arg.clone(),
+        },
+        lpar: list_comp.lpar.clone(),
+        rpar: list_comp.rpar.clone(),
+    }));
+
+    let mut state = Default::default();
+    tree.codegen(&mut state);
+
+    Ok(Fix::replacement(
+        state.to_string(),
+        expr.location,
+        expr.end_location.unwrap(),
+    ))
+}
+
 /// (C405) Convert `set((1, 2))` to `{1, 2}`.
 pub fn fix_unnecessary_literal_set(
     locator: &SourceCodeLocator,
@@ -591,6 +650,92 @@ pub fn fix_unnecessary_list_call(
     ))
 }
 
+/// (C413) Convert `list(sorted([2, 3, 1]))` to `sorted([2, 3, 1])`.
+/// (C413) Convert `reversed(sorted([2, 3, 1]))` to `sorted([2, 3, 1],
+/// reverse=True)`.
+pub fn fix_unnecessary_call_around_sorted(
+    locator: &SourceCodeLocator,
+    expr: &rustpython_ast::Expr,
+) -> Result<Fix> {
+    let module_text = locator.slice_source_code_range(&Range::from_located(expr));
+    let mut tree = match_module(&module_text)?;
+    let mut body = match_expr(&mut tree)?;
+    let outer_call = match_call(body)?;
+    let inner_call = match &outer_call.args[..] {
+        [arg] => {
+            if let Expression::Call(call) = &arg.value {
+                call
+            } else {
+                return Err(anyhow::anyhow!("Expected node to be: Expression::Call "));
+            }
+        }
+        _ => {
+            return Err(anyhow::anyhow!(
+                "Expected one argument in outer function call"
+            ))
+        }
+    };
+
+    if let Expression::Name(outer_name) = &*outer_call.func {
+        if outer_name.value == "list" {
+            body.value = Expression::Call(inner_call.clone());
+        } else {
+            let args = if inner_call.args.iter().any(|arg| {
+                matches!(
+                    arg.keyword,
+                    Some(Name {
+                        value: "reverse",
+                        ..
+                    })
+                )
+            }) {
+                inner_call.args.clone()
+            } else {
+                let mut args = inner_call.args.clone();
+                args.push(Arg {
+                    value: Expression::Name(Box::new(Name {
+                        value: "True",
+                        lpar: Default::default(),
+                        rpar: Default::default(),
+                    })),
+                    keyword: Some(Name {
+                        value: "reverse",
+                        lpar: Default::default(),
+                        rpar: Default::default(),
+                    }),
+                    equal: Some(AssignEqual {
+                        whitespace_before: Default::default(),
+                        whitespace_after: Default::default(),
+                    }),
+                    comma: Default::default(),
+                    star: Default::default(),
+                    whitespace_after_star: Default::default(),
+                    whitespace_after_arg: Default::default(),
+                });
+                args
+            };
+
+            body.value = Expression::Call(Box::new(Call {
+                func: inner_call.func.clone(),
+                args,
+                lpar: inner_call.lpar.clone(),
+                rpar: inner_call.rpar.clone(),
+                whitespace_after_func: inner_call.whitespace_after_func.clone(),
+                whitespace_before_args: inner_call.whitespace_before_args.clone(),
+            }))
+        }
+    }
+
+    let mut state = Default::default();
+    tree.codegen(&mut state);
+
+    Ok(Fix::replacement(
+        state.to_string(),
+        expr.location,
+        expr.end_location.unwrap(),
+    ))
+}
+
 /// (C416) Convert `[i for i in x]` to `list(x)`.
 pub fn fix_unnecessary_comprehension(
     locator: &SourceCodeLocator,
