@@ -115,7 +115,7 @@ pub fn useless_object_inheritance(name: &str, bases: &[Expr], scope: &Scope) ->
     for expr in bases {
         if let ExprKind::Name { id, .. } = &expr.node {
             if id == "object" {
-                match scope.values.get(id) {
+                match scope.values.get(&id.as_str()) {
                     None
                     | Some(Binding {
                         kind: BindingKind::Builtin,
@@ -163,7 +163,8 @@ pub fn type_of_primitive(func: &Expr, args: &[Expr], location: Range) -> Option<
 pub fn unnecessary_lru_cache_params(
     decorator_list: &[Expr],
     target_version: PythonVersion,
-    imports: &FnvHashMap<&str, FnvHashSet<&str>>,
+    from_imports: &FnvHashMap<&str, FnvHashSet<&str>>,
+    import_aliases: &FnvHashMap<&str, &str>,
 ) -> Option<Check> {
     for expr in decorator_list.iter() {
         if let ExprKind::Call {
@@ -172,7 +173,14 @@ pub fn unnecessary_lru_cache_params(
             keywords,
         } = &expr.node
         {
-            if args.is_empty() && helpers::match_module_member(func, "functools.lru_cache", imports)
+            if args.is_empty()
+                && helpers::match_module_member(
+                    func,
+                    "functools",
+                    "lru_cache",
+                    from_imports,
+                    import_aliases,
+                )
             {
                 // Ex) `functools.lru_cache()`
                 if keywords.is_empty() {
