@@ -2,6 +2,9 @@ pub use deprecated_unittest_alias::deprecated_unittest_alias;
 pub use super_call_with_parameters::super_call_with_parameters;
 pub use type_of_primitive::type_of_primitive;
 pub use unnecessary_abspath::unnecessary_abspath;
+pub use unnecessary_encode_utf8::unnecessary_encode_utf8;
+pub use unnecessary_future_import::unnecessary_future_import;
+pub use unnecessary_lru_cache_params::unnecessary_lru_cache_params;
 pub use use_pep585_annotation::use_pep585_annotation;
 pub use use_pep604_annotation::use_pep604_annotation;
 pub use useless_metaclass_type::useless_metaclass_type;
@@ -11,6 +14,9 @@ mod deprecated_unittest_alias;
 mod super_call_with_parameters;
 mod type_of_primitive;
 mod unnecessary_abspath;
+mod unnecessary_encode_utf8;
+mod unnecessary_future_import;
+mod unnecessary_lru_cache_params;
 mod use_pep585_annotation;
 mod use_pep604_annotation;
 mod useless_metaclass_type;
