@@ -6,6 +6,7 @@ use crate::autofix::helpers;
 use crate::check_ast::Checker;
 use crate::pyupgrade::checks;
 
+/// U001
 pub fn useless_metaclass_type(checker: &mut Checker, stmt: &Stmt, value: &Expr, targets: &[Expr]) {
     if let Some(mut check) =
         checks::useless_metaclass_type(targets, value, Range::from_located(stmt))
@@ -29,7 +30,7 @@ pub fn useless_metaclass_type(checker: &mut Checker, stmt: &Stmt, value: &Expr,
                     }
                     check.amend(fix)
                 }
-                Err(e) => error!("Failed to fix unused imports: {}", e),
+                Err(e) => error!("Failed to fix remove metaclass type: {}", e),
             }
         }
         checker.add_check(check);
